@@ -1,4 +1,4 @@
-# $Revision: 1.7 $$Date: 2003/03/18 16:00:11 $$Author: wsnyder $
+# $Revision: 1.9 $$Date: 2003/07/03 15:06:37 $$Author: wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -19,7 +19,7 @@
 ######################################################################
 
 package P4::C4::Fstat;
-require 5.6.0;
+require 5.006_001;
 
 use strict;
 use vars qw($VERSION);
@@ -28,7 +28,7 @@ use Carp;
 ######################################################################
 #### Configuration Section
 
-$VERSION = '2.010';
+$VERSION = '2.020';
 
 #######################################################################
 #######################################################################
